@@ -1,9 +1,6 @@
-#' mmapcharr.
-#'
-#' @name mmapcharr
-#' @docType package
-#' 
 #' @useDynLib mmapcharr, .registration = TRUE
 #' @importFrom Rcpp sourceCpp
 #' @importFrom methods new
-NULL
+#' 
+#' @keywords internal
+"_PACKAGE"
